# CVXPY DNLP Differentiation Engine

This repository contains a **C implementation of the differentiation engine used by CVXPY** for its extension to **Disciplined Nonlinear Programming** [(DNLP)](https://github.com/cvxgrp/DNLP).

The library provides low-level routines for computing sparse Jacobians and Hessians required by nonlinear programming solvers. The library is intended as a **backend component** and is not meant to be used directly by end users.

